<?php
	define('PREPEND_PATH', '');
	include_once(__DIR__ . '/lib.php');

	// accept a record as an assoc array, return transformed row ready to insert to table
	$transformFunctions = [
		'Revenue' => function($data, $options = []) {

			return $data;
		},
		'Expenditure' => function($data, $options = []) {

			return $data;
		},
		'Pickup_Request' => function($data, $options = []) {
			if(isset($data['date'])) $data['date'] = guessMySQLDateTime($data['date']);
			if(isset($data['phone_number'])) $data['phone_number'] = str_replace('-', '', $data['phone_number']);

			return $data;
		},
		'Riders' => function($data, $options = []) {

			return $data;
		},
		'Delivery_setup' => function($data, $options = []) {

			return $data;
		},
		'Signin' => function($data, $options = []) {

			return $data;
		},
		'signout' => function($data, $options = []) {

			return $data;
		},
		'Delivery_loggings' => function($data, $options = []) {
			if(isset($data['date'])) $data['date'] = guessMySQLDateTime($data['date']);

			return $data;
		},
		'Loans' => function($data, $options = []) {
			if(isset($data['date'])) $data['date'] = guessMySQLDateTime($data['date']);

			return $data;
		},
		'Assets' => function($data, $options = []) {
			if(isset($data['date_acquired'])) $data['date_acquired'] = guessMySQLDateTime($data['date_acquired']);

			return $data;
		},
	];

	// accept a record as an assoc array, return a boolean indicating whether to import or skip record
	$filterFunctions = [
		'Revenue' => function($data, $options = []) { return true; },
		'Expenditure' => function($data, $options = []) { return true; },
		'Pickup_Request' => function($data, $options = []) { return true; },
		'Riders' => function($data, $options = []) { return true; },
		'Delivery_setup' => function($data, $options = []) { return true; },
		'Signin' => function($data, $options = []) { return true; },
		'signout' => function($data, $options = []) { return true; },
		'Delivery_loggings' => function($data, $options = []) { return true; },
		'Loans' => function($data, $options = []) { return true; },
		'Assets' => function($data, $options = []) { return true; },
	];

	/*
	Hook file for overwriting/amending $transformFunctions and $filterFunctions:
	hooks/import-csv.php
	If found, it's included below

	The way this works is by either completely overwriting any of the above 2 arrays,
	or, more commonly, overwriting a single function, for example:
		$transformFunctions['tablename'] = function($data, $options = []) {
			// new definition here
			// then you must return transformed data
			return $data;
		};

	Another scenario is transforming a specific field and leaving other fields to the default
	transformation. One possible way of doing this is to store the original transformation function
	in GLOBALS array, calling it inside the custom transformation function, then modifying the
	specific field:
		$GLOBALS['originalTransformationFunction'] = $transformFunctions['tablename'];
		$transformFunctions['tablename'] = function($data, $options = []) {
			$data = call_user_func_array($GLOBALS['originalTransformationFunction'], [$data, $options]);
			$data['fieldname'] = 'transformed value';
			return $data;
		};
	*/

	@include(__DIR__ . '/hooks/import-csv.php');

	$ui = new CSVImportUI($transformFunctions, $filterFunctions);
