<?php
	// check this file's MD5 to make sure it wasn't called before
	$tenantId = Authentication::tenantIdPadded();
	$setupHash = __DIR__ . "/setup{$tenantId}.md5";

	$prevMD5 = @file_get_contents($setupHash);
	$thisMD5 = md5_file(__FILE__);

	// check if this setup file already run
	if($thisMD5 != $prevMD5) {
		// set up tables
		setupTable(
			'Revenue', " 
			CREATE TABLE IF NOT EXISTS `Revenue` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`trip_details` TEXT NOT NULL,
				`amount` INT NOT NULL,
				`rider` VARCHAR(40) NULL
			) CHARSET utf8mb4"
		);

		setupTable(
			'Expenditure', " 
			CREATE TABLE IF NOT EXISTS `Expenditure` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`expenses_details` TEXT NOT NULL,
				`amount` INT NOT NULL,
				`staff` VARCHAR(40) NULL,
				`photo` VARCHAR(40) NULL
			) CHARSET utf8mb4"
		);

		setupTable(
			'Pickup_Request', " 
			CREATE TABLE IF NOT EXISTS `Pickup_Request` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`date` DATE NULL,
				`item_description` VARCHAR(40) NOT NULL,
				`phone_number` INT NOT NULL,
				`location_in_words` VARCHAR(40) NULL,
				`location` VARCHAR(255) NOT NULL,
				`item_picture` VARCHAR(40) NULL
			) CHARSET utf8mb4"
		);

		setupTable(
			'Riders', " 
			CREATE TABLE IF NOT EXISTS `Riders` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`name` VARCHAR(40) NOT NULL,
				`ghana_card` VARCHAR(40) NOT NULL,
				`riders_license` VARCHAR(40) NOT NULL,
				`police_clearance` VARCHAR(40) NULL,
				`location` VARCHAR(40) NOT NULL,
				`educational_qualification` VARCHAR(40) NULL,
				`passport_picture` VARCHAR(40) NOT NULL
			) CHARSET utf8mb4"
		);

		setupTable(
			'Delivery_setup', " 
			CREATE TABLE IF NOT EXISTS `Delivery_setup` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`item_description` VARCHAR(40) NULL,
				`status` VARCHAR(40) NOT NULL,
				`staff` VARCHAR(40) NULL,
				`updated` VARCHAR(40) NULL,
				`address` VARCHAR(40) NULL,
				`location` VARCHAR(40) NULL,
				`recipient_number` VARCHAR(40) NULL
			) CHARSET utf8mb4"
		);

		setupTable(
			'Signin', " 
			CREATE TABLE IF NOT EXISTS `Signin` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`time` VARCHAR(40) NULL,
				`fuel_image` VARCHAR(40) NULL
			) CHARSET utf8mb4"
		);

		setupTable(
			'signout', " 
			CREATE TABLE IF NOT EXISTS `signout` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`time` VARCHAR(40) NULL,
				`fuel` VARCHAR(40) NULL,
				`fuel_image` VARCHAR(40) NULL
			) CHARSET utf8mb4"
		);

		setupTable(
			'Delivery_loggings', " 
			CREATE TABLE IF NOT EXISTS `Delivery_loggings` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`date` DATE NULL,
				`location` VARCHAR(40) NULL,
				`photo_of_item` VARCHAR(40) NULL,
				`rider` VARCHAR(40) NULL,
				`amount` DECIMAL(10,2) NULL
			) CHARSET utf8mb4"
		);

		setupTable(
			'Loans', " 
			CREATE TABLE IF NOT EXISTS `Loans` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`date` DATE NULL,
				`creditor` VARCHAR(40) NULL,
				`amount` INT NOT NULL,
				`by` VARCHAR(40) NULL
			) CHARSET utf8mb4", [
				" ALTER TABLE `Loans` CHANGE `amount` `amount` INT NULL ",
				" ALTER TABLE `Loans` CHANGE `amount` `amount` INT NOT NULL ",
			]
		);

		setupTable(
			'Assets', " 
			CREATE TABLE IF NOT EXISTS `Assets` ( 
				`id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
				PRIMARY KEY (`id`),
				`date_acquired` DATE NULL,
				`name` VARCHAR(40) NULL,
				`reciept` VARCHAR(40) NULL,
				`amount` INT NOT NULL,
				`by` VARCHAR(40) NULL
			) CHARSET utf8mb4", [
				" ALTER TABLE `Assets` CHANGE `amount` `amount` INT NULL ",
				" ALTER TABLE `Assets` CHANGE `amount` `amount` INT NOT NULL ",
			]
		);



		// save MD5
		@file_put_contents($setupHash, $thisMD5);
	}


	function setupIndexes($tableName, $arrFields) {
		if(!is_array($arrFields) || !count($arrFields)) return false;

		foreach($arrFields as $fieldName) {
			if(!$res = @db_query("SHOW COLUMNS FROM `$tableName` like '$fieldName'")) continue;
			if(!$row = @db_fetch_assoc($res)) continue;
			if($row['Key']) continue;

			@db_query("ALTER TABLE `$tableName` ADD INDEX `$fieldName` (`$fieldName`)");
		}
	}


	function setupTable($tableName, $createSQL = '', $arrAlter = '') {
		global $Translation;
		$oldTableName = '';
		ob_start();

		echo '<div style="padding: 5px; border-bottom:solid 1px silver; font-family: verdana, arial; font-size: 10px;">';

		// is there a table rename query?
		if(is_array($arrAlter)) {
			$matches = [];
			if(preg_match("/ALTER TABLE `(.*)` RENAME `$tableName`/i", $arrAlter[0], $matches)) {
				$oldTableName = $matches[1];
			}
		}

		if($res = @db_query("SELECT COUNT(1) FROM `$tableName`")) { // table already exists
			if($row = @db_fetch_array($res)) {
				echo str_replace(['<TableName>', '<NumRecords>'], [$tableName, $row[0]], $Translation['table exists']);
				if(is_array($arrAlter)) {
					echo '<br>';
					foreach($arrAlter as $alter) {
						if($alter != '') {
							echo "$alter ... ";
							if(!@db_query($alter)) {
								echo '<span class="label label-danger">' . $Translation['failed'] . '</span>';
								echo '<div class="text-danger">' . $Translation['mysql said'] . ' ' . db_error(db_link()) . '</div>';
							} else {
								echo '<span class="label label-success">' . $Translation['ok'] . '</span>';
							}
						}
					}
				} else {
					echo $Translation['table uptodate'];
				}
			} else {
				echo str_replace('<TableName>', $tableName, $Translation['couldnt count']);
			}
		} else { // given tableName doesn't exist

			if($oldTableName != '') { // if we have a table rename query
				if($ro = @db_query("SELECT COUNT(1) FROM `$oldTableName`")) { // if old table exists, rename it.
					$renameQuery = array_shift($arrAlter); // get and remove rename query

					echo "$renameQuery ... ";
					if(!@db_query($renameQuery)) {
						echo '<span class="label label-danger">' . $Translation['failed'] . '</span>';
						echo '<div class="text-danger">' . $Translation['mysql said'] . ' ' . db_error(db_link()) . '</div>';
					} else {
						echo '<span class="label label-success">' . $Translation['ok'] . '</span>';
					}

					if(is_array($arrAlter)) setupTable($tableName, $createSQL, false, $arrAlter); // execute Alter queries on renamed table ...
				} else { // if old tableName doesn't exist (nor the new one since we're here), then just create the table.
					setupTable($tableName, $createSQL, false); // no Alter queries passed ...
				}
			} else { // tableName doesn't exist and no rename, so just create the table
				echo str_replace("<TableName>", $tableName, $Translation["creating table"]);
				if(!@db_query($createSQL)) {
					echo '<span class="label label-danger">' . $Translation['failed'] . '</span>';
					echo '<div class="text-danger">' . $Translation['mysql said'] . db_error(db_link()) . '</div>';

					// create table with a dummy field
					@db_query("CREATE TABLE IF NOT EXISTS `$tableName` (`_dummy_deletable_field` TINYINT)");
				} else {
					echo '<span class="label label-success">' . $Translation['ok'] . '</span>';
				}
			}

			// set Admin group permissions for newly created table if membership_grouppermissions exists
			if($ro = @db_query("SELECT COUNT(1) FROM `membership_grouppermissions`")) {
				// get Admins group id
				$ro = @db_query("SELECT `groupID` FROM `membership_groups` WHERE `name`='Admins'");
				if($ro) {
					$adminGroupID = intval(db_fetch_row($ro)[0]);
					if($adminGroupID) @db_query("INSERT IGNORE INTO `membership_grouppermissions` SET
						`groupID`='$adminGroupID',
						`tableName`='$tableName',
						`allowInsert`=1, `allowView`=1, `allowEdit`=1, `allowDelete`=1
					");
				}
			}
		}

		echo '</div>';

		$out = ob_get_clean();
		if(defined('APPGINI_SETUP') && APPGINI_SETUP) echo $out;
	}
